@@ -13,7 +13,9 @@ my $GraphDummies = $mw->Bars(
   -title     => 'My chart title - overwrite',
   -xlabel    => 'X Label',
   -ylabel    => 'Y Label',
-  -overwrite => 1
+  -overwrite => 1,
+  -showvalues => 1,
+  -longticks  => 1,
 )->pack(qw / -fill both -expand 1 /);
 
 my @data = (
@@ -22,6 +24,17 @@ my @data = (
   [ 1,     2,     4,     6,     3,     17.5,  1,     20,    10 ]
 );
 
+# Add a legend to the chart
+my @Legends = ( 'legend 1', 'legend 2', );
+$GraphDummies->set_legend(
+  -title       => "Title legend",
+  -data        => \@Legends,
+  -titlecolors => "blue",
+);
+
+# Add help identification
+$GraphDummies->set_balloon();
+
 # Create the chart
 $GraphDummies->plot( \@data );
 
